@@ -382,8 +382,7 @@ static void merge_styles(
     {
       SAFEFREE(SGET_FORE_COLOR_NAME_HI(*merged_style));
       SSET_FORE_COLOR_NAME_HI(
-	*merged_style, (SGET_FORE_COLOR_NAME_HI(*add_style)) ?
-	strdup(SGET_FORE_COLOR_NAME_HI(*add_style)) : NULL);
+	*merged_style, SGET_FORE_COLOR_NAME_HI(*add_style));
     }
     else
     {
@@ -397,8 +396,7 @@ static void merge_styles(
     {
       SAFEFREE(SGET_BACK_COLOR_NAME_HI(*merged_style));
       SSET_BACK_COLOR_NAME_HI(
-	*merged_style, (SGET_BACK_COLOR_NAME_HI(*add_style)) ?
-	strdup(SGET_BACK_COLOR_NAME_HI(*add_style)) : NULL);
+	*merged_style, SGET_BACK_COLOR_NAME_HI(*add_style));
     }
     else
     {
@@ -424,22 +422,6 @@ static void merge_styles(
     SSET_WINDOW_SHADE_STEPS(*merged_style, SGET_WINDOW_SHADE_STEPS(*add_style));
   }
 
-  /* merge the style flags */
-  merge_flags = (char *)&(merged_style->flags);
-  add_flags = (char *)&(add_style->flags);
-  merge_mask = (char *)&(merged_style->flag_mask);
-  add_mask = (char *)&(add_style->flag_mask);
-  merge_change_mask = (char *)&(merged_style->change_mask);
-  add_change_mask = (char *)&(add_style->change_mask);
-  for (i = 0; i < sizeof(style_flags); i++)
-  {
-    merge_flags[i] |= (add_flags[i] & add_mask[i]);
-    merge_flags[i] &= (add_flags[i] | ~add_mask[i]);
-    merge_mask[i] |= add_mask[i];
-    merge_change_mask[i] &= ~(add_mask[i]);
-    merge_change_mask[i] |= add_change_mask[i];
-  }
-
   /* Note, only one style cmd can define a windows iconboxes,
    * the last one encountered. */
   if (SHAS_ICON_BOXES(&add_style->flags))
@@ -448,11 +430,7 @@ static void merge_styles(
     /* copy it */
     if (do_free)
     {
-#if 1
-      free_icon_boxes(SGET_ICON_BOXES(*merged_style));
-#else
       remove_icon_boxes_from_style(merged_style);
-#endif
       copy_icon_boxes(
 	&SGET_ICON_BOXES(*merged_style), SGET_ICON_BOXES(*add_style));
     }
@@ -481,6 +459,26 @@ static void merge_styles(
   {
     SSET_BORDER_COLORSET_HI(*merged_style,SGET_BORDER_COLORSET_HI(*add_style));
   }
+
+  /* merge the style flags */
+
+  /*** ATTENTION:
+   ***   This must be the last thing that is done in this function! */
+  merge_flags = (char *)&(merged_style->flags);
+  add_flags = (char *)&(add_style->flags);
+  merge_mask = (char *)&(merged_style->flag_mask);
+  add_mask = (char *)&(add_style->flag_mask);
+  merge_change_mask = (char *)&(merged_style->change_mask);
+  add_change_mask = (char *)&(add_style->change_mask);
+  for (i = 0; i < sizeof(style_flags); i++)
+  {
+    merge_flags[i] |= (add_flags[i] & add_mask[i]);
+    merge_flags[i] &= (add_flags[i] | ~add_mask[i]);
+    merge_mask[i] |= add_mask[i];
+    merge_change_mask[i] &= ~(add_mask[i]);
+    merge_change_mask[i] |= add_change_mask[i];
+  }
+
   merged_style->has_style_changed |= add_style->has_style_changed;
   return;
 }
@@ -1447,9 +1445,9 @@ void ProcessNewStyle(F_CMD_ARGS)
 	else if (StrEquals(token, "IconOverride"))
 	{
 	  found = True;
-	  ptmpstyle->flags.icon_override = ICON_OVERRIDE;
-	  ptmpstyle->flag_mask.icon_override = ICON_OVERRIDE_MASK;
-	  ptmpstyle->change_mask.icon_override = ICON_OVERRIDE_MASK;
+	  SFSET_ICON_OVERRIDE(*ptmpstyle, ICON_OVERRIDE);
+	  SMSET_ICON_OVERRIDE(*ptmpstyle, ICON_OVERRIDE_MASK);
+	  SCSET_ICON_OVERRIDE(*ptmpstyle, ICON_OVERRIDE_MASK);
 	}
         else if (StrEquals(token, "IgnoreRestack"))
         {
@@ -1814,16 +1812,16 @@ void ProcessNewStyle(F_CMD_ARGS)
 	if (StrEquals(token, "NoActiveIconOverride"))
 	{
 	  found = True;
-	  ptmpstyle->flags.icon_override = NO_ACTIVE_ICON_OVERRIDE;
-	  ptmpstyle->flag_mask.icon_override = ICON_OVERRIDE_MASK;
-	  ptmpstyle->change_mask.icon_override = ICON_OVERRIDE_MASK;
+	  SFSET_ICON_OVERRIDE(*ptmpstyle, NO_ACTIVE_ICON_OVERRIDE);
+	  SMSET_ICON_OVERRIDE(*ptmpstyle, ICON_OVERRIDE_MASK);
+	  SCSET_ICON_OVERRIDE(*ptmpstyle, ICON_OVERRIDE_MASK);
 	}
 	else if (StrEquals(token, "NoIconOverride"))
 	{
 	  found = True;
-	  ptmpstyle->flags.icon_override = NO_ICON_OVERRIDE;
-	  ptmpstyle->flag_mask.icon_override = ICON_OVERRIDE_MASK;
-	  ptmpstyle->change_mask.icon_override = ICON_OVERRIDE_MASK;
+	  SFSET_ICON_OVERRIDE(*ptmpstyle, NO_ICON_OVERRIDE);
+	  SMSET_ICON_OVERRIDE(*ptmpstyle, ICON_OVERRIDE_MASK);
+	  SCSET_ICON_OVERRIDE(*ptmpstyle, ICON_OVERRIDE_MASK);
 	}
         else if (StrEquals(token, "NoIconTitle"))
         {
@@ -1853,6 +1851,13 @@ void ProcessNewStyle(F_CMD_ARGS)
           ptmpstyle->flag_mask.use_no_pposition = 1;
           ptmpstyle->change_mask.use_no_pposition = 1;
         }
+        else if (StrEquals(token, "NoIconPosition"))
+        {
+	  found = True;
+	  SFSET_USE_ICON_POSITION_HINT(*ptmpstyle, 0);
+	  SMSET_USE_ICON_POSITION_HINT(*ptmpstyle, 1);
+	  SCSET_USE_ICON_POSITION_HINT(*ptmpstyle, 1);
+        }
         else if (StrEquals(token, "NakedTransient"))
         {
 	  found = True;
@@ -2285,6 +2290,13 @@ void ProcessNewStyle(F_CMD_ARGS)
           ptmpstyle->flag_mask.use_no_pposition = 1;
           ptmpstyle->change_mask.use_no_pposition = 1;
         }
+        else if (StrEquals(token, "UseIconPosition"))
+        {
+	  found = True;
+	  SFSET_USE_ICON_POSITION_HINT(*ptmpstyle, 1);
+	  SMSET_USE_ICON_POSITION_HINT(*ptmpstyle, 1);
+	  SCSET_USE_ICON_POSITION_HINT(*ptmpstyle, 1);
+        }
 #ifdef USEDECOR
         if (StrEquals(token, "UseDecor"))
         {
@@ -2421,6 +2433,8 @@ void ProcessNewStyle(F_CMD_ARGS)
   {
     if(ptmpstyle->flags.has_icon == 1)
     {
+      if (Scr.DefaultIcon)
+	free(Scr.DefaultIcon);
       Scr.DefaultIcon = SGET_ICON_NAME(*ptmpstyle);
       ptmpstyle->flags.has_icon = 0;
       ptmpstyle->flag_mask.has_icon = 0;
@@ -2583,7 +2597,7 @@ void check_window_style_change(
    * icon_override
    */
   if (ret_style->change_mask.has_icon ||
-      ret_style->change_mask.icon_override)
+      SCICON_OVERRIDE(*ret_style))
   {
     flags->do_update_icon_font = True;
     flags->do_update_icon = True;
@@ -2686,7 +2700,7 @@ void check_window_style_change(
 
   /*
    * has_ol_decor
-0   */
+   */
   if (ret_style->change_mask.has_ol_decor)
   {
     /* old decor overrides 'has_no_icon_title'! */
