@@ -1346,18 +1346,18 @@ void CreateShadowGC(void)
 
   gcv.foreground = fore_pix;
   gcv.background = back_pix;
-  NormalGC = XCreateGC(dpy, main_win, gcm, &gcv);
+  NormalGC = fvwmlib_XCreateGC(dpy, main_win, gcm, &gcv);
   gcv.foreground = back_pix;
   gcv.background = fore_pix;
-  HiReliefGC = XCreateGC(dpy, main_win, gcm, &gcv);
+  HiReliefGC = fvwmlib_XCreateGC(dpy, main_win, gcm, &gcv);
 
   gcv.foreground = light_grey;
   gcv.background = fore_pix;
-  HiInnerGC = XCreateGC(dpy, main_win, gcm, &gcv);
+  HiInnerGC = fvwmlib_XCreateGC(dpy, main_win, gcm, &gcv);
 
   gcm = GCForeground;
   gcv.foreground = fore_pix;
-  MaskGC = XCreateGC(dpy, main_win, gcm, &gcv);
+  MaskGC = fvwmlib_XCreateGC(dpy, main_win, gcm, &gcv);
 }
 
 /************************************************************************
@@ -1566,17 +1566,21 @@ void ParseOptions(char *filename)
       {
 	tmp++;
       }
-      tmp[strlen(tmp)-1] = 0;
+      if (strlen(tmp) > 0)
+      {
+	if (isspace(tmp[strlen(tmp)-1]))
+	  tmp[strlen(tmp)-1] = 0;
 
-      flags = XParseGeometry(tmp,&g_x,&g_y,&width,&height);
-      if (flags & WidthValue)
-	w = width;
-      if (flags & HeightValue)
-	h = height;
-      if (flags & XValue)
-	x = g_x;
-      if (flags & YValue)
-	y = g_y;
+	flags = XParseGeometry(tmp,&g_x,&g_y,&width,&height);
+	if (flags & WidthValue)
+	  w = width;
+	if (flags & HeightValue)
+	  h = height;
+	if (flags & XValue)
+	  x = g_x;
+	if (flags & YValue)
+	  y = g_y;
+      }
     }
     else if((strncasecmp(tline,CatString3("*",MyName,"Rows"),Clength+5)==0))
     {
